@@ -80,18 +80,32 @@ def draw_wire(ctx, width, source_top, target_top):
     ctx.stroke()
 
 
-def draw_wiremap_cairo(ctx, width, height, connections, shorts, color):
-    colors = [
-        (0, 0, 0),
-        (1, 0.6, 0.26),
-        (1, 0.6, 0.26),
-        (0.26, 0.86, 0.26),
-        (0, 0.5, 1),
-        (0, 0.5, 1),
-        (0.26, 0.86, 0.26),
-        (0.5, 0.33, 0),
-        (0.5, 0.33, 0),
-    ]
+def draw_wiremap_cairo(ctx, width, height, connections, shorts, color, colorscheme):
+    scheme = {
+        'T568 A': [
+            (0, 0, 0),
+            (0.26, 0.86, 0.26),
+            (0.26, 0.86, 0.26),
+            (1, 0.6, 0.26),
+            (0, 0.5, 1),
+            (0, 0.5, 1),
+            (1, 0.6, 0.26),
+            (0.5, 0.33, 0),
+            (0.5, 0.33, 0),
+        ],
+        'T568 B': [
+            (0, 0, 0),
+            (1, 0.6, 0.26),
+            (1, 0.6, 0.26),
+            (0.26, 0.86, 0.26),
+            (0, 0.5, 1),
+            (0, 0.5, 1),
+            (0.26, 0.86, 0.26),
+            (0.5, 0.33, 0),
+            (0.5, 0.33, 0),
+        ]
+    }
+    colors = scheme[colorscheme]
 
     for connection_from, connection_to in enumerate(connections):
         top = connection_from * 16 + 10.5
